mast

package
v0.1.5 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2026 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package mast provides a remote provider for the Mikulski Archive for Space Telescopes.

The mast package bridges the STScI Common Archive Observation Model (CAOM) REST endpoints dynamically resolving identifiers via the standard Mast.Name.Lookup module. Returned objects correspond to datasets from missions like Hubble (HST), James Webb Space Telescope (JWST), TESS, and Kepler natively parsed into ICRS targets.

Index

Constants

This section is empty.

Variables

var ErrAPIError = errors.New("mast: API error")

ErrAPIError indicates a MAST API error response.

Functions

This section is empty.

Types

type Provider

type Provider struct {
	// contains filtered or unexported fields
}

Provider implements the resolve.Provider interface for the MAST catalog.

func New

func New() *Provider

New creates a new MAST provider.

func (*Provider) Capabilities

func (p *Provider) Capabilities() []resolve.Capability

Capabilities returns the capabilities of the provider.

func (*Provider) ConeSearch

ConeSearch implements cone search using CAOM.

func (*Provider) Name

func (p *Provider) Name() string

Name returns the name of the provider.

func (*Provider) Resolve

func (p *Provider) Resolve(query string) (resolve.Target, bool)

Resolve resolves a query to a target.

func (*Provider) ResolveObject

ResolveObject resolves a query to a target.

func (*Provider) Search

func (p *Provider) Search(query string) []resolve.Target

Search searches for targets matching the query.

Jump to